<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://profiles.wordpress.org/dots
 * @since      1.0.0
 *
 * @package    Gdpr_Compliance_Toolkit
 * @subpackage Gdpr_Compliance_Toolkit/admin
 */
/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Gdpr_Compliance_Toolkit
 * @subpackage Gdpr_Compliance_Toolkit/admin
 * @author     Multidots <inquiry@multidots.in>
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Gdpr_Compliance_Toolkit_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string $plugin_name The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string $version The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 *
	 * @param      string $plugin_name The name of this plugin.
	 * @param      string $version     The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version     = $version;
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Gdpr_Compliance_Toolkit_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Gdpr_Compliance_Toolkit_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		if ( isset( $_GET['page'] ) &&
		     ! empty( $_GET['page'] ) &&
		     ( $_GET['page'] == 'gdpr-user-request-data-list' ||
		       $_GET['page'] == 'gdpr-list' ||
		       $_GET['page'] == 'gdpr-order-data-list' ||
		       $_GET['page'] == 'gdpr-get-started' ||
		       $_GET['page'] == 'gdpr-information' ||
		       $_GET['page'] == 'gdpr-general-setting'
		     ) ) {
			wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/gdpr-compliance-toolkit-admin.css', array(), $this->version, 'all' );
			wp_enqueue_style( $this->plugin_name . 'main-style', plugin_dir_url( __FILE__ ) . 'css/style.css', array(), $this->version, 'all' );
			wp_enqueue_style( $this->plugin_name . 'font-awesome', plugin_dir_url( __FILE__ ) . 'css/font-awesome.min.css', array(), $this->version, 'all' );
			wp_enqueue_style( $this->plugin_name . 'media-css', plugin_dir_url( __FILE__ ) . 'css/media.css', array(), $this->version, 'all' );
		}
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Gdpr_Compliance_Toolkit_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Gdpr_Compliance_Toolkit_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_enqueue_script( 'jquery' );
		wp_enqueue_script( 'jquery-ui-core' );
		wp_enqueue_script( 'jquery-ui-sortable' );
		wp_enqueue_script( 'jquery-ui-accordion' );
		wp_enqueue_style( 'wp-jquery-ui-dialog' );
		if ( isset( $_GET['page'] ) &&
		     ! empty( $_GET['page'] ) &&
		     ( $_GET['page'] == 'gdpr-user-request-data-list' ||
		       $_GET['page'] == 'gdpr-list' ||
		       $_GET['page'] == 'gdpr-order-data-list' ||
		       $_GET['page'] == 'gdpr-get-started' ||
		       $_GET['page'] == 'gdpr-information' ||
		       $_GET['page'] == 'gdpr-general-setting'
		     ) ) {
			wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/gdpr-compliance-toolkit-admin.js', array(
				'jquery',
				'jquery-ui-dialog',
				'jquery-ui-accordion',
				'jquery-ui-sortable',
				'wp-color-picker',
			), $this->version, false );
			wp_localize_script( $this->plugin_name, 'adminajax', array(
				'ajaxurl'   => admin_url( 'admin-ajax.php' ),
				'ajax_icon' => plugin_dir_url( __FILE__ ) . '/images/ajax-loader.gif',
			) );
			wp_enqueue_script( $this->plugin_name . 'tablesorter', plugin_dir_url( __FILE__ ) . 'js/jquery.tablesorter.js', array( 'jquery' ), $this->version, false );
			$email_success_msg     = __( 'Email has been send successfully : ', 'gdpr-compliance-toolkit' );
			$email_not_success_msg = __( 'Email has not been send successfully : ', 'gdpr-compliance-toolkit' );
			$custom_email_msg      = __( 'Because he has not been confirmed.', 'gdpr-compliance-toolkit' );
			$custom_email_msg1     = __( 'You can not send mail this ', 'gdpr-compliance-toolkit' );
			$dismiss_msg           = __( 'Dismiss this notice.', 'gdpr-compliance-toolkit' );
			wp_localize_script( $this->plugin_name, 'email_success_msg', array(
					'EmailSuccessMsg'    => $email_success_msg,
					'EmailNotSuccessMsg' => $email_not_success_msg,
					'CustomEmailMsg'     => $custom_email_msg,
					'CustomEmailMsg1'    => $custom_email_msg1,
					'DismissMsg'         => $dismiss_msg,
				)
			);
		}
	}

	/**
	 * Register the Page for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function gdprct_dot_store_menu() {
		global $GLOBALS;
		if ( empty( $GLOBALS['admin_page_hooks']['dots_store'] ) ) {
			add_menu_page(
				'DotStore Plugins', __( 'DotStore Plugins' ), 'manage_option', 'dots_store', array(
				$this,
				'gdprct_data_list_page',
			), GDPR_PLUGIN_URL . 'admin/images/menu-icon.png', 25
			);
		}
		add_submenu_page( 'dots_store', 'Get Started', 'Get Started', 'manage_options', 'gdpr-get-started', array( $this, 'gdprct_get_started_page' ) );
		add_submenu_page( 'dots_store', 'Introduction', 'Introduction', 'manage_options', 'gdpr-information', array( $this, 'gdprct_information_page' ) );
		add_submenu_page( 'dots_store', 'GDPR Compliance Toolkit', __( GDPR_COMPLIANCE_TOOLKIT_PLUGIN_NAME ), 'manage_options', 'gdpr-list', array(
			$this,
			'gdprct_data_list_page',
		) );
		add_submenu_page( 'dots_store', 'GDPR Order Data List', 'GDPR Order Data List', 'manage_options', 'gdpr-order-data-list', array( $this, 'gdprct_order_data_list' ) );
		add_submenu_page( 'dots_store', 'GDPR User Request Data List', 'GDPR User Request Data List', 'manage_options', 'gdpr-user-request-data-list', array(
			$this,
			'gdprct_user_request_data_list',
		) );
		add_submenu_page( 'dots_store', 'GDPR Setting', 'GDPR Setting', 'manage_options', 'gdpr-general-setting', array( $this, 'gdprct_general_setting' ) );
	}

	/**
	 * Register the Information Page for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function gdprct_information_page() {
		require_once( 'partials/gdpr-information-page.php' );
	}

	/**
	 * Register the GDPR List for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function gdprct_data_list_page() {
		require_once( 'partials/gdpr-list-page.php' );
	}

	/**
	 * Register the GDPR user request list for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function gdprct_user_request_data_list() {
		require_once( 'partials/gdpr-user-request-data-list.php' );
	}

	/**
	 * Register the GDPR order data list for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function gdprct_order_data_list() {
		require_once( 'partials/gdpr-order-data-list.php' );
	}

	/**
	 * Register the Get Started Page for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function gdprct_get_started_page() {
		require_once( 'partials/gdpr-get-started-page.php' );
	}

	/**
	 * Extra setting for GDPR
	 *
	 * @since    1.0.0
	 */
	public function gdprct_general_setting() {
		require_once( 'partials/gdpr-general-setting.php' );
	}

	/**
	 * Welcome Screen Redirect.
	 *
	 * @since    1.0.0
	 */
	public function gdprct_welcome_screen_do_activation_redirect() {
		// if no activation redirect
		if ( ! get_transient( '_welcome_screen_activation_redirect_gdpr' ) ) {
			return;
		}

		// Delete the redirect transient
		delete_transient( '_welcome_screen_activation_redirect_gdpr' );

		// if activating from network, or bulk
		if ( is_network_admin() || isset( $_GET['activate-multi'] ) ) {
			return;
		}
		// Redirect to extra cost welcome  page

		wp_safe_redirect( add_query_arg( array( 'page' => 'gdpr-get-started' ), admin_url( 'admin.php' ) ) );
	}

	/**
	 * Remove Menu from toolbar which is display in admin section.
	 *
	 * @since    1.0.0
	 */
	public function gdprct_remove_admin_submenus() {
		remove_submenu_page( 'dots_store', 'gdpr-information' );
		remove_submenu_page( 'dots_store', 'gdpr-premium' );
		remove_submenu_page( 'dots_store', 'gdpr-get-started' );
		remove_submenu_page( 'dots_store', 'gdpr-order-data-list' );
		remove_submenu_page( 'dots_store', 'gdpr-user-request-data-list' );
		remove_submenu_page( 'dots_store', 'gdpr-extra-setting' );
	}

	public function gdpr_integration_save( $post ) {
		global $wpdb;
		if ( empty( $post ) ) {
			return false;
		}

		$gdprfrm = wp_create_nonce( 'gdprfrm' );

		if ( isset( $post['woocommerce_integration'] ) && ! empty( $post['woocommerce_integration'] ) ) {
			$woocommerce_integration = 'on';
		} else {
			$woocommerce_integration = 'off';
		}

		$woo_integration = $post['woo_integration'];

		$json_array = array( 'woo_integration' => $woo_integration );

		update_option( 'gdpr_compilation_toolkit', json_encode( $json_array ) );

		$latest_url = esc_url( home_url( '/wp-admin/admin.php?page=gdpr-list&_wpnonce=' . esc_attr( $gdprfrm ) ) );

		$newUrl = html_entity_decode( $latest_url );

		wp_safe_redirect( $newUrl );
		exit();
	}

	public function get_wc_data( $order_id_arr ) {
		global $wpdb;
		$order_detail = array();
		if ( ! empty( $order_id_arr ) ) {

			foreach ( $order_id_arr as $key => $order_id ) {

				$order      = new WC_Order( $order_id );
				$order_post = get_post( $order_id );
				$dp         = isset( $filter['dp'] ) ? intval( $filter['dp'] ) : 2;

				$billing_first_name = $order->get_billing_first_name();
				$billing_last_name  = $order->get_billing_last_name();
				$billing_company    = $order->get_billing_company();
				$billing_address_1  = $order->get_billing_address_1();
				$billing_address_2  = $order->get_billing_address_2();
				$billing_city       = $order->get_billing_city();
				$billing_state      = $order->get_billing_state();
				$billing_postcode   = $order->get_billing_postcode();
				$billing_country    = $order->get_billing_country();
				$billing_email      = $order->get_billing_email();
				$billing_phone      = $order->get_billing_phone();

				$shipping_first_name = $order->get_shipping_first_name();
				$shipping_last_name  = $order->get_shipping_last_name();
				$shipping_company    = $order->get_shipping_company();
				$shipping_address_1  = $order->get_shipping_address_1();
				$shipping_address_2  = $order->get_shipping_address_2();
				$shipping_city       = $order->get_shipping_city();
				$shipping_state      = $order->get_shipping_state();
				$shipping_postcode   = $order->get_shipping_postcode();
				$shipping_country    = $order->get_shipping_country();

				$order_number              = $order->get_order_number();
				$created_at                = $order_post->post_date;
				$updated_at                = $order_post->post_modified;
				$completed_at              = ! empty( $order->get_date_completed() ) ? $order->get_date_completed() : '';
				$status                    = $order->get_status();
				$currency                  = $order->get_currency();
				$total                     = wc_format_decimal( $order->get_total(), $dp );
				$subtotal                  = wc_format_decimal( $order->get_subtotal(), $dp );
				$total_line_items_quantity = $order->get_item_count();
				$total_tax                 = wc_format_decimal( $order->get_total_tax(), $dp );
				$total_shipping            = wc_format_decimal( $order->get_total_shipping(), $dp );
				$cart_tax                  = wc_format_decimal( $order->get_cart_tax(), $dp );
				$shipping_tax              = wc_format_decimal( $order->get_shipping_tax(), $dp );
				$total_discount            = wc_format_decimal( $order->get_total_discount(), $dp );
				$shipping_methods          = $order->get_shipping_method();
				$order_key                 = $order->get_order_key();
				$method_id                 = $order->get_payment_method();
				$method_title              = $order->get_payment_method_title();
				$paid_at                   = ! empty( $order->get_date_paid() ) ? $order->get_date_paid() : '';

				$order_detail[ $order_id ] = array(
					"billing_first_name"        => $billing_first_name,
					"billing_last_name"         => $billing_last_name,
					"billing_company"           => $billing_company,
					"billing_address_1"         => $billing_address_1,
					"billing_address_2"         => $billing_address_2,
					"billing_city"              => $billing_city,
					"billing_state"             => $billing_state,
					"billing_postcode"          => $billing_postcode,
					"billing_country"           => $billing_country,
					"billing_email"             => $billing_email,
					"billing_phone"             => $billing_phone,
					"shipping_first_name"       => $shipping_first_name,
					"shipping_last_name"        => $shipping_last_name,
					"shipping_company"          => $shipping_company,
					"shipping_address_1"        => $shipping_address_1,
					"shipping_address_2"        => $shipping_address_2,
					"shipping_city"             => $shipping_city,
					"shipping_state"            => $shipping_state,
					"shipping_postcode"         => $shipping_postcode,
					"shipping_country"          => $shipping_country,
					"order_number"              => $order_number,
					"created_at"                => $created_at,
					"updated_at"                => $updated_at,
					"completed_at"              => $completed_at,
					"status"                    => $status,
					"currency"                  => $currency,
					"total"                     => $total,
					"subtota"                   => $subtotal,
					"total_line_items_quantity" => $total_line_items_quantity,
					"total_tax"                 => $total_tax,
					"total_shipping"            => $total_shipping,
					"cart_tax"                  => $cart_tax,
					"shipping_tax"              => $shipping_tax,
					"total_discount"            => $total_discount,
					"shipping_methods"          => $shipping_methods,
					"order_key"                 => $order_key,
					"method_id"                 => $method_id,
					"method_title"              => $method_title,
					"paid_at"                   => $paid_at,
				);
			}
		}

		return $order_detail;
	}

	/**
	 * Delete checked gdpr id from gdpr page.
	 *
	 * @since    1.0.0
	 */
	public function gdprct_delete_selected_gdpr_using_checkbox() {
		global $wpdb;

		$selected_gdpr_id = isset( $_REQUEST['selected_gdpr_id'] ) ? $_REQUEST['selected_gdpr_id'] : '';

		$success_delete = array();
		if ( ! empty( $selected_gdpr_id ) && isset( $selected_gdpr_id ) ) {
			foreach ( $selected_gdpr_id as $key => $value ) {
				$success_delete[] = delete_post_meta( $value, '_gdpr' );
			}
			if ( in_array( 1, $success_delete ) ) {
				echo esc_html__( 'true', 'gdpr-compliance-toolkit' );
				wp_die();
			}
		}
	}

	/**
	 * Delete single gdpr id from gdpr page.
	 *
	 * @since    1.0.0
	 *
	 * @return string Its return true
	 */
	public function gdprct_delete_single_gdpr_using_button() {
		$single_selected_gdpr_id = isset( $_REQUEST['single_selected_gdpr_id'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['single_selected_gdpr_id'] ) ) : '';

		$success_delete = delete_post_meta( $single_selected_gdpr_id, '_gdpr' );

		if ( '1' == $success_delete ) {
			echo esc_html__( 'true', 'gdpr-compliance-toolkit' );
			wp_die();
		}
	}

	/**
	 * Send mail to selected single user
	 *
	 * @since    1.0.0
	 *
	 * @return string Its return true
	 */
	public function gdprct_send_mail_single_gdpr_using_button() {

		global $wpdb;
		$wpfp_prefix                   = GDPR_WP_TABLE_PREFIX . GDPR_PRO_TABLE_PREFIX;
		$wp_gdpr_personal_data_request = $wpfp_prefix . "personal_data_request";
		$email_id                      = isset( $_REQUEST['get_email'] ) ? trim( sanitize_text_field( wp_unslash( $_REQUEST['get_email'] ) ) ) : '';
		$get_id                        = isset( $_REQUEST['get_id'] ) ? trim( sanitize_text_field( wp_unslash( $_REQUEST['get_id'] ) ) ) : '';

		$user = get_user_by( 'email', $email_id );

		$user_data = $user->data;

		$result = $this->gdprct_email_function( $email_id, $user_data );

		if ( 'true' == $result ) {
			$status        = 'confirm';
			$update_result = $wpdb->query( $wpdb->prepare( "UPDATE `" . $wp_gdpr_personal_data_request . "` SET `status` = %s WHERE `email` = %s AND `id` = %d", trim( stripslashes( sanitize_text_field( $status ) ) ), $email_id, intval( $get_id ) ) );

			if ( $update_result == '1' ) {
				echo esc_html__( 'true', 'gdpr-compliance-toolkit' );
				wp_die();
			} else {
				echo esc_html__( 'already_sent', 'gdpr-compliance-toolkit' );
				wp_die();
			}
		}
		die;
	}

	/**
	 * @param $links
	 * @param $file
	 *
	 * @return array
	 */
	function check_page_visit_plugin_row_meta( $links, $file ) {

		if ( strpos( $file, 'gdpr-compliance-toolkit.php' ) !== false ) {
			$new_links = array(
				'support' => '<a href="https://www.thedotstore.com/support/" target="_blank">Support</a>',
			);

			$links = array_merge( $links, $new_links );
		}

		return $links;
	}

	/**
	 * Send mail to selected single user
	 *
	 * @since    1.0.0
	 *
	 * @param string $email_id
	 *
	 * @param array  $user_data
	 *
	 * @return string Its return true
	 */
	public function gdprct_email_function( $email_id, $user_data ) {
		$message = '';
		$message .= '&nbsp;';
		$message .= '<table style="width: 700px; margin: auto; text-align: center; border: 1px solid #eee; font-family: sans-serif; border-collapse: collapse;">';
		$message .= '<thead>';
		$message .= '<tr>';
		$message .= '<td style="color: white; font-size: 20px; background: #1266ae; text-align: center; padding: 20px 0px;" colspan="2">' . __( 'Data which is storage in this website', 'gdpr-compliance-toolkit' ) . '</td>';
		$message .= '</tr>';
		$message .= '</thead>';
		$message .= '<tbody>';
		$message .= '<tr style="border: 1px solid #e4e4e4;">';
		$message .= '<td style="padding: 5px; font-size: 15px; border: 1px solid #e4e4e4;">' . __( 'User Login', 'gdpr-compliance-toolkit' ) . '</td>';
		$message .= '<td style="padding: 5px; font-size: 15px;">' . $user_data->user_login . '</td>';
		$message .= '</tr>';
		$message .= '<tr style="border: 1px solid #e4e4e4;">';
		$message .= '<td style="padding: 5px; font-size: 15px; border: 1px solid #e4e4e4;">' . __( 'User Password', 'gdpr-compliance-toolkit' ) . '</td>';
		$message .= '<td style="padding: 5px; font-size: 15px;">' . $user_data->user_pass . '</td>';
		$message .= '</tr>';
		$message .= '<tr style="border: 1px solid #e4e4e4;">';
		$message .= '<td style="padding: 5px; font-size: 15px; border: 1px solid #e4e4e4;">' . __( 'User Nicename', 'gdpr-compliance-toolkit' ) . '</td>';
		$message .= '<td style="padding: 5px; font-size: 15px;">' . $user_data->user_nicename . '</td>';
		$message .= '</tr>';
		$message .= '<tr style="border: 1px solid #e4e4e4;">';
		$message .= '<td style="padding: 5px; font-size: 15px; border: 1px solid #e4e4e4;">' . __( 'User Email', 'gdpr-compliance-toolkit' ) . '</td>';
		$message .= '<td style="padding: 5px; font-size: 15px;">' . $user_data->user_email . '</td>';
		$message .= '</tr>';
		$message .= '<tr style="border: 1px solid #e4e4e4;">';
		$message .= '<td style="padding: 5px; font-size: 15px; border: 1px solid #e4e4e4;">' . __( 'User URL', 'gdpr-compliance-toolkit' ) . '</td>';
		$message .= '<td style="padding: 5px; font-size: 15px;">' . $user_data->user_url . '</td>';
		$message .= '</tr>';
		$message .= '<tr style="border: 1px solid #e4e4e4;">';
		$message .= '<td style="padding: 5px; font-size: 15px; border: 1px solid #e4e4e4;">' . __( 'User Activation Key', 'gdpr-compliance-toolkit' ) . '</td>';
		$message .= '<td style="padding: 5px; font-size: 15px;">' . $user_data->user_activation_key . '</td>';
		$message .= '</tr>';
		$message .= '<tr style="border: 1px solid #e4e4e4;">';
		$message .= '<td style="padding: 5px; font-size: 15px; border: 1px solid #e4e4e4;">' . __( 'User Registered', 'gdpr-compliance-toolkit' ) . '</td>';
		$message .= '<td style="padding: 5px; font-size: 15px;">' . $user_data->user_registered . '</td>';
		$message .= '</tr>';
		$message .= '<tr style="border: 1px solid #e4e4e4;">';
		$message .= '<td style="padding: 5px; font-size: 15px; border: 1px solid #e4e4e4;">' . __( 'Display Name', 'gdpr-compliance-toolkit' ) . '</td>';
		$message .= '<td style="padding: 5px; font-size: 15px;">' . $user_data->display_name . '</td>';
		$message .= '</tr>';
		$message .= '</tbody>';
		$message .= '<tfoot>';
		$message .= '<tr>';
		$message .= '<td style="color: #000; padding: 15px; background: #e4e4e4;" colspan="2">' . get_bloginfo( 'name' ) . '</td>';
		$message .= '</tr>';
		$message .= '</tfoot>';
		$message .= '</table>';
		$message .= '&nbsp;';

		/* Admin email */
		$get_gdpr_general_setting = $this->gdprct_get_general_setting();
		$admin_email              = isset( $get_gdpr_general_setting['gdpr_admin_email'] ) && ! empty( $get_gdpr_general_setting['gdpr_admin_email'] ) ? sanitize_text_field( wp_unslash( $get_gdpr_general_setting['gdpr_admin_email'] ) ) : get_option( 'admin_email' );

		$to           = $admin_email;
		$subject      = __( 'Send Storage Data to this ', 'gdpr-compliance-toolkit' ) . $email_id;
		$body         = $message;
		$headers      = array( 'Content-Type: text/html; charset=UTF-8' );
		$admin_result = wp_mail( $to, $subject, $body, $headers );

		/* User email */
		$user_to      = $email_id;
		$user_subject = __( 'Your Storage Data In This Website', 'gdpr-compliance-toolkit' );
		$user_body    = $message;
		$user_headers = array( 'Content-Type: text/html; charset=UTF-8' );
		$user_result  = wp_mail( $user_to, $user_subject, $user_body, $user_headers );

		if ( 'true' == $admin_result && 'true' == $user_result ) {
			return 'true';
		} else {
			return 'false';
		}
	}

	/**
	 * Get general setting detail
	 *
	 * @since    1.0.0
	 *
	 * @return mixed|array
	 */
	public function gdprct_get_general_setting() {
		$gdpr_general_setting = json_decode( get_option( 'gdpr_general_setting' ), true );
		return $gdpr_general_setting;
	}

	/**
	 * Send mail to all selected user
	 *
	 * @since    1.0.0
	 *
	 * @return string Its return true
	 */
	public function gdprct_send_mail_selected_gdpr_using_checkbox() {

		global $wpdb;
		$wpfp_prefix                   = GDPR_WP_TABLE_PREFIX . GDPR_PRO_TABLE_PREFIX;
		$wp_gdpr_personal_data_request = $wpfp_prefix . "personal_data_request";
		$selected_mail_gdpr            = isset( $_REQUEST['selected_mail_gdpr'] ) ? $_REQUEST['selected_mail_gdpr'] : '';


		$success_mail = array();
		if ( ! empty( $selected_mail_gdpr ) && isset( $selected_mail_gdpr ) ) {
			foreach ( $selected_mail_gdpr as $key => $value ) {
				$value_explode  = explode( '||', $value );
				$email_id       = trim( $value_explode[1] );
				$get_id         = trim( $value_explode[0] );
				$user           = get_user_by( 'email', $email_id );
				$user_data      = $user->data;
				$result         = $this->gdprct_email_function( $email_id, $user_data );
				$success_mail[] = $result;
				if ( 'true' == $result ) {
					$status        = 'confirm';
					$update_result = $wpdb->query( $wpdb->prepare( "UPDATE `" . $wp_gdpr_personal_data_request . "` SET `status` = %s WHERE `email` = %s AND `id` = %d", trim( stripslashes( sanitize_text_field( $status ) ) ), $email_id, intval( $get_id ) ) );
				}
			}
			if ( in_array( 'true', $success_mail ) ) {
				echo esc_html__( 'true', 'gdpr-compliance-toolkit' );
				wp_die();
			}
		}
	}

	/**
	 * Send mail to selected single user
	 *
	 * @since    1.0.0
	 *
	 * @param string $email_id
	 *
	 * @return string Its return true
	 */
	public function gdprct_email_function_for_front_side( $email_id ) {

		$hash_email   = base64_encode( $email_id );
		$verify_url   = site_url() . '/my-account/my-gdpr-data?&request=' . $hash_email;
		$verify_a_tag = '<a href="' . $verify_url . '" style="padding: 15px; background: #1275f3; display: inline-block; margin-top: 20px; color: #ffffff; font-size: 20px; text-decoration: none;">' . __( 'Confirm', 'gdpr-compliance-toolkit' ) . '</a>';

		/* Admin email */
		$admin_message = '';
		$admin_message .= '<div style="display: block; text-align: center; width: 40%; margin: 0 auto; background: #504d4d14; padding: 50px;">';
		$admin_message .= '<h2 style=font-size: 35px; word-break: break-word;">' . __( 'GDPR Woocommerce Request', 'gdpr-compliance-toolkit' ) . '</h2>';
		$admin_message .= '<div style="display: block;text-align: center; font-size: 18px;line-height: 30px;">' . __( 'The user has requested for his data. His email is ', 'gdpr-compliance-toolkit' ) . ' ' . $email_id . '</div>';
		$admin_message .= $email_id;
		$admin_message .= '</div>';

		$get_gdpr_general_setting = $this->gdprct_get_general_setting();
		$admin_email              = isset( $get_gdpr_general_setting['gdpr_admin_email'] ) && ! empty( $get_gdpr_general_setting['gdpr_admin_email'] ) ? sanitize_text_field( wp_unslash( $get_gdpr_general_setting['gdpr_admin_email'] ) ) : get_option( 'admin_email' );

		$to      = $admin_email;
		$subject = __( 'GDPR Data requests', 'gdpr-compliance-toolkit' );
		$body    = $admin_message;
		$headers = array( 'Content-Type: text/html; charset=UTF-8' );

		$admin_result = wp_mail( $to, $subject, $body, $headers );

		/* User email */
		$user_message = '';
		$user_message .= '<div style="display: block; text-align: center; width: 40%; margin: 0 auto; background: #504d4d14; padding: 50px;">';
		$user_message .= '<h2 style=font-size: 35px; word-break: break-word;">' . __( 'GDPR Woocommerce Request', 'gdpr-compliance-toolkit' ) . '</h2>';
		$user_message .= '<div style="display: block;text-align: center; font-size: 18px;line-height: 30px;">' . __( 'If you requested you personal data report from us please click the link below to confirm your email address and proceed with the request. If you DID NOT request it, Please ignore thie email', 'gdpr-compliance-toolkit' ) . '</div>';
		$user_message .= $verify_a_tag;
		$user_message .= '</div>';

		$user_to      = $email_id;
		$user_subject = __( 'GDPR Data requests', 'gdpr-compliance-toolkit' );
		$user_body    = $user_message;
		$user_headers = array( 'Content-Type: text/html; charset=UTF-8' );
		$user_result  = wp_mail( $user_to, $user_subject, $user_body, $user_headers );

		if ( 'true' == $admin_result && 'true' == $user_result ) {
			return 'true';
		} else {
			return 'false';
		}
	}
	/**
	 * Simple Pagination
	 *
	 * @since    1.0.0
	 * @param string $paged
	 * @param string $max_page
	 */
	public function pagination( $paged = '', $max_page = '' ) {
		$big = 999999999;

		echo paginate_links( array(
			'base'      => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
			'format'    => '?paged=%#%',
			'current'   => max( 1, $paged ),
			'total'     => $max_page,
			'mid_size'  => 1,
			'prev_text' => __( '«' ),
			'next_text' => __( '»' ),
			'type'      => 'list',
		) ); // WPCS: XSS OK.
	}

	public function gdprct_extra_setting_save( $post ) {

		if ( empty( $post ) ) {
			return false;
		}
		$gdprsettingformnonce = wp_create_nonce( 'gdprsettingform' );

		$gdpr_setting = array(
			'gdpr_admin_email'      => $post['gdpr_admin_email'],
			'gdpr_backend_per_page' => $post['gdpr_backend_per_page'],
		);

		update_option( 'gdpr_general_setting', json_encode( $gdpr_setting ) );

		$latest_url = esc_url( home_url( '/wp-admin/admin.php?page=gdpr-general-setting&_wpnonce=' . wp_kses_post( $gdprsettingformnonce ) ) );
		$newUrl     = html_entity_decode( $latest_url );

		wp_safe_redirect( $newUrl );
		exit();
	}
}