<?php
if (!defined('ABSPATH')) {
    exit;
}
require_once( 'header/plugin-header.php' );

global $wpdb;
$wpfp_prefix = GDPR_WP_TABLE_PREFIX . GDPR_PRO_TABLE_PREFIX;
$wp_gdpr_personal_data_request = $wpfp_prefix . "personal_data_request";

/* General Setting */
$gdpr_admin_obj = new Gdpr_Compliance_Toolkit_Admin( $this->plugin_name, $this->version );
$gdpr_general_setting = $gdpr_admin_obj->gdprct_get_general_setting();
$gdpr_backend_per_page = !empty($gdpr_general_setting['gdpr_backend_per_page']) ? trim($gdpr_general_setting['gdpr_backend_per_page']) : GDPR_DEFAULT_PER_PAGE;

$retrieved_nonce = empty($_REQUEST['_wpnonce']) ? '' : sanitize_text_field(wp_unslash($_REQUEST['_wpnonce']));

if (isset($_REQUEST['action']) && 'delete' == $_REQUEST['action'] ) {
    if (!wp_verify_nonce($retrieved_nonce, 'wppgdprnonce')) {
        die('Failed security check');
    }
}

if (isset($_REQUEST["paged"]) && !empty($_REQUEST['paged'])) {
    $page = intval(sanitize_text_field(wp_unslash($_REQUEST['paged'])));
} else {
    $page = 1;
}

$limit = ( isset($_REQUEST["limit"]) && sanitize_text_field(wp_unslash($_REQUEST["limit"])) <> "" && is_numeric(sanitize_text_field(wp_unslash($_REQUEST["limit"]))) ) ? intval(sanitize_text_field(wp_unslash($_REQUEST["limit"]))) : $gdpr_backend_per_page;

$page_result = $wpdb->get_row('SELECT COUNT(*) AS total_id FROM ' . $wp_gdpr_personal_data_request);
$total_records = $page_result->total_id;

$last = ceil($total_records / $limit);

if ($page < 1) {
    $page = 1;
} elseif ($page > $last) {
    $page = $last;
}

if ($page > 1) {
    $lower_limit = ( $page - 1 ) * $limit;
} else {
    $lower_limit = '0';
}

$sel_qry = $wpdb->prepare('SELECT * FROM ' . $wp_gdpr_personal_data_request . ' LIMIT %d, %d', $lower_limit, $limit);
$gdpr_usr_re_data_qry = $wpdb->get_results($sel_qry);


wp_nonce_field('send_mail');
?>
<div class="gdpr-main-table res-cl" id="gdpr_user_request_data">
    <div class="product_header_title">
        <h2>
            <?php esc_html_e('GDPR User List', 'gdpr-compliance-toolkit'); ?>
            <a id="send_mail_all_selected_gdpr" class="send_mail_all_selected_gdpr button-primary add-new-btn" href="javascript:void(0);" disabled="disabled"><?php esc_html_e('Send Mail', 'gdpr-compliance-toolkit'); ?></a>
        </h2>
    </div>
    <table id="gdpr-listing" class="table-outer form-table all-table-listing tablesorter">
        <thead>
            <tr class="gdpr-head">
                <th><input type="checkbox" name="check_all_mail_checkbox" class="chk_all_gdpr_class" id="chk_all_gdpr_send_mail"></th>
                <th><?php esc_html_e('Email', 'gdpr-compliance-toolkit'); ?></th>
                <th><?php esc_html_e('Request Time', 'gdpr-compliance-toolkit'); ?></th>
                <th><?php esc_html_e('Status', 'gdpr-compliance-toolkit'); ?></th>
                <th><?php esc_html_e('Confirm Mail By User', 'gdpr-compliance-toolkit'); ?></th>
                <th><?php esc_html_e('Send Mail', 'gdpr-compliance-toolkit'); ?></th>
            </tr>
        </thead>
        <tbody>
            <?php
            if (!empty($gdpr_usr_re_data_qry) && isset($gdpr_usr_re_data_qry)) {
                $i = 1;
                foreach ($gdpr_usr_re_data_qry as $sel_key => $sel_data) {
                    $main_id = $sel_data->id;
                    $email = $sel_data->email;
                    $request_date_time = $sel_data->request_date_time;
                    $status = ucwords($sel_data->status);
                    $conf_mail_by_user = ucwords($sel_data->conf_mail_by_user);
                    $wpfpnonce = wp_create_nonce('wppgdprnonce');
                    ?>
                    <tr id="gdpr_mail_row_<?php echo $main_id; ?>">
                        <td width="5%">
                            <input type="checkbox" class="chk_single_send_mail_gdpr" name="chk_single_send_mail_gdpr" value="<?php echo esc_attr($main_id); ?>">
                        </td>
                        <td>
                            <?php esc_html_e($email, 'gdpr-compliance-toolkit'); ?>
                        </td>
                        <td>
                            <?php esc_html_e($request_date_time, 'gdpr-compliance-toolkit'); ?>
                        </td>
                        <td>
                            <?php esc_html_e($status, 'gdpr-compliance-toolkit'); ?>
                        </td>
                        <td>
                            <?php esc_html_e($conf_mail_by_user, 'gdpr-compliance-toolkit'); ?>
                        </td>
                        <td>
                            <a class="fee-action-button button-primary send_mail_single_selected_gdpr" href="javascript:void(0);" id="send_mail_single_selected_gdpr_<?php echo esc_attr($main_id); ?>" ><?php esc_html_e('Send Mail', 'gdpr-compliance-toolkit'); ?></a>
                        </td>
                    </tr>
                    <?php
                    $i++;
                }
            } else {
                ?>
                <tr>
                    <td colspan="6" class="no_list">
                        <?php esc_html_e('No List Available', 'gdpr-compliance-toolkit'); ?>
                    </td>
                </tr>
                <?php
            }
            ?>
        </tbody>
    </table>
    <?php
    echo $pagination_question_list = $gdpr_admin_obj->pagination($page, $last);
    ?>
</div>
<?php
require_once( 'header/plugin-sidebar.php' );