<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://profiles.wordpress.org/dots
 * @since             1.0.0
 * @package           Gdpr_Compliance_Toolkit
 *
 * @wordpress-plugin
 * Plugin Name:       GDPR Compliance Toolkit
 * Plugin URI:        https://wordpress.org/plugins/gdpr-compliance-toolkit/
 * Description:       This plugin assists WooCommercs store owners to comply with European privacy regulations known as GDPR. By May 24th, 2018 your website owners have to comply to avoid large fines. 
 * Version:           1.0.4
 * Author:            Thedotstore
 * Author URI:        https://www.thedotstore.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       gdpr-compliance-toolkit
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( !defined( 'ABSPATH' ) ) {
    exit;
}
if (!defined('GDPR_PLUGIN_URL')) {
    define('GDPR_PLUGIN_URL', plugin_dir_url(__FILE__));
}
if (!defined('GDPR_PLUGIN_DIR')) {
    define('GDPR_PLUGIN_DIR', dirname(__FILE__));
}
if (!defined('GDPR_PLUGIN_DIR_PATH')) {
    define('GDPR_PLUGIN_DIR_PATH', plugin_dir_path(__FILE__));
}
if (!defined('GDPR_PLUGIN_BASENAME')) {
    define('GDPR_PLUGIN_BASENAME', plugin_basename(__FILE__));
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'GDPR_PLUGIN_NAME_VERSION', '1.0.4' );

/**
 * The core plugin include constant file for set constant.
 */
require plugin_dir_path(__FILE__) . 'includes/constant.php';

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-gdpr-compliance-toolkit-activator.php
 */
function activate_gdpr_compliance_toolkit() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-gdpr-compliance-toolkit-activator.php';
	Gdpr_Compliance_Toolkit_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-gdpr-compliance-toolkit-deactivator.php
 */
function deactivate_gdpr_compliance_toolkit() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-gdpr-compliance-toolkit-deactivator.php';
	Gdpr_Compliance_Toolkit_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_gdpr_compliance_toolkit' );
register_deactivation_hook( __FILE__, 'deactivate_gdpr_compliance_toolkit' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-gdpr-compliance-toolkit.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_gdpr_compliance_toolkit() {

	$plugin = new Gdpr_Compliance_Toolkit();
	$plugin->run();

}
run_gdpr_compliance_toolkit();

function gdpr_compliance_toolkit_plugin_path() {
  return untrailingslashit( plugin_dir_path( __FILE__ ) );
}