<?php

/**
 * Fired during plugin activation
 *
 * This class defines all code necessary to run during the plugin's activation.
 *
 * @link       https://profiles.wordpress.org/dots
 * @since      1.0.0
 * @package    Gdpr_Compliance_Toolkit
 * @subpackage Gdpr_Compliance_Toolkit/includes
 * @author     Multidots <inquiry@multidots.in>
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Gdpr_Compliance_Toolkit_Activator {

	/**
	 * Short Description. (use period)
	 *
	 * Long Description.
	 *
	 * @since    1.0.0
	 */
	public static function activate() {
		if ( ! in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) && ! is_plugin_active_for_network( 'woocommerce/woocommerce.php' ) ) {
			wp_die( "<strong> " . GDPR_COMPLIANCE_TOOLKIT_PLUGIN_NAME . "</strong> Plugin requires <strong>WooCommerce</strong> <a href='" . get_admin_url( null, 'plugins.php' ) . "'>" . esc_html__( 'Plugins page', 'woo-product-finder-pro' ) . "</a>." );
		} else {
			global $wpdb;
			require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
			$charset_collate = $wpdb->get_charset_collate();
			/* Plugin's table prefix */
			$wpfp_prefix = $wpdb->prefix . 'gdpr_';

			/* Table name */
			$wp_gdpr_personal_data_request = $wpfp_prefix . "personal_data_request";

			if ( $wpdb->get_var( "SHOW TABLES LIKE '" . $wp_gdpr_personal_data_request . "'" ) != $wp_gdpr_personal_data_request ) {
				$sql = "CREATE TABLE " . $wp_gdpr_personal_data_request . " ( 
                  id int( 11 ) NOT NULL AUTO_INCREMENT,
                  email text NOT NULL,
                  request_date_time varchar( 255 ) NOT NULL,
                  status varchar( 255 ) NOT NULL,
                  conf_mail_by_user varchar( 255 ) NOT NULL,
                  PRIMARY KEY  ( id )
                   );";
			}
			dbDelta( $sql );
			set_transient( '_welcome_screen_activation_redirect_gdpr', true, 30 );
			add_option( 'gdprct_version', Gdpr_Compliance_Toolkit::GDPRCT_VERSION );
		}
	}
}