<?php
/**
 * GDPR Form
 */
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}
$retrieved_nonce = empty($_REQUEST['_wpnonce']) ? '' : sanitize_text_field(wp_unslash($_REQUEST['_wpnonce']));
$request_data = empty($_REQUEST['request']) ? '' : sanitize_text_field(wp_unslash($_REQUEST['request']));

global $wpdb;
$wpfp_prefix = GDPR_WP_TABLE_PREFIX . GDPR_PRO_TABLE_PREFIX;
$wp_gdpr_personal_data_request = $wpfp_prefix . "personal_data_request";

if (isset($request_data) && !empty($request_data)) {
    $request_email = base64_decode($request_data);
    $conf_mail_by_user = 'confirm';
    $update_result = $wpdb->query($wpdb->prepare("UPDATE " . $wp_gdpr_personal_data_request . " SET conf_mail_by_user = %s WHERE email = %s", trim(stripslashes(sanitize_text_field($conf_mail_by_user))), trim(stripslashes(sanitize_text_field($request_email)))));
} else {
    $request_email = '';
}
if (isset($_POST['submit'])) {
    if (!wp_verify_nonce($retrieved_nonce, 'gdprmyaccoutfrm')) {
        die('Failed security check');
    } else {
        $email = trim(sanitize_text_field(wp_unslash($_POST['email'])));

        $gdprAdminObject = new Gdpr_Compliance_Toolkit_Admin($this->plugin_name, $this->version);
        $result = $gdprAdminObject->gdprct_email_function_for_front_side($email);

        if ($result == 'true') {
            $current_date_time = date("Y-m-d H:i:s");
            $status = 'pending';
            $conf_mail_by_user = 'pending';
            $result_option = $wpdb->query($wpdb->prepare("INSERT INTO " . $wp_gdpr_personal_data_request . "( email, request_date_time, status, conf_mail_by_user ) VALUES ( %s, %s, %s, %s )", trim($email), trim($current_date_time), trim($status), trim($conf_mail_by_user)));
        }
    }
}
?>

<?php wc_print_notices(); ?>


<div class="u-columns col2-set" id="gdpr_data">
    <div class="u-column">
        <h2><?php _e('GDPR Personal Data Request', 'gdpr-compliance-toolkit'); ?></h2>
        <?php
        if (isset($request_data) && !empty($request_data)) {
            ?>
            <div id="request_email_msg"><?php echo wp_kses_post('Thanks for verify GDPR request data. You will get your data as soon as possible on this email : ' . $request_email, 'gdpr-compliance-toolkit') ?></div>
            <?php
        }
        ?>
        <div class="gdpr_desc">
            <p><?php _e('To get your GDPR report you will have to follow the steps as below:', 'gdpr-compliance-toolkit'); ?></p>
            <ul class="gdpr_desc_ul">
                <li><?php _e('1. Submit your email in the form below.', 'gdpr-compliance-toolkit'); ?></li>
                <li><?php _e('2. A confirmation email will be sent to you, you need to click the confirmation button/link in the email.', 'gdpr-compliance-toolkit'); ?></li>
                <li><?php _e('3. A GDPR report will be emailed to you.', 'gdpr-compliance-toolkit'); ?></li>
            </ul>
        </div>
        <form class="woocommerce-form woocommerce-form-gdpr gdpr" method="post">
            <?php wp_nonce_field('gdprmyaccoutfrm'); ?>
            <p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
                <label for="email"><?php _e('Email address', 'gdpr-compliance-toolkit'); ?> <span class="required">*</span></label>
                <input type="text" class="woocommerce-Input woocommerce-Input--email input-email" name="email" id="email" value="" required="required"/>
            </p>

            <p class="form-row">
                <?php wp_nonce_field('gdpr-data', 'gdpr-data-nonce'); ?>
                <input type="submit" class="woocommerce-Button button" name="submit" value="<?php esc_attr_e('Submit', 'gdpr-compliance-toolkit'); ?>" />
            </p>
        </form>
    </div>
    <div class="u-column">
        <h2><?php _e('Right to Data Rectification', 'gdpr-compliance-toolkit'); ?></h2>
        <?php
        if (isset($request_data) && !empty($request_data)) {
            ?>
            <div id="request_email_msg"><?php echo wp_kses_post('Thanks for verify GDPR request data. You will get your data as soon as possible on this email : ' . $request_email, 'gdpr-compliance-toolkit') ?></div>
            <?php
        }
        ?>
        <div class="gdpr_desc">
            <p><?php _e('To update your account data please use the links below.', 'gdpr-compliance-toolkit'); ?></p>
        </div>
        <?php
        $my_account_url = site_url() . '/my-account/edit-account/';
        ?>
        <a href="<?php echo esc_url($my_account_url); ?>"><?php _e('Click Here', 'gdpr-compliance-toolkit'); ?></a>
    </div>
</div>